pub struct VectorPath {
pub anchors: Vec<Anchor>,
pub closed: bool,
}Fields
anchors: Vec<Anchor>closed: boolImplementations
Sourceimpl VectorPath
impl VectorPath
pub fn segment_count(&self) -> usize
pub fn to_bez_path(&self) -> BezPath
pub fn from_bez_path(path: &BezPath) -> Self
Sourcepub fn nearest_segment(&self, point: DVec2) -> Option<(usize, f64, f64)>
pub fn nearest_segment(&self, point: DVec2) -> Option<(usize, f64, f64)>
Return (segment_index, t_param, distance) for the nearest cubic segment.
pub fn hit_test(&self, p: DVec2, tol: f64) -> Option<PathHit>
Sourcepub fn insert_anchor_at(
&mut self,
seg: usize,
t: f64,
) -> Result<(), GeometryError>
pub fn insert_anchor_at( &mut self, seg: usize, t: f64, ) -> Result<(), GeometryError>
De Casteljau split of segment seg at parameter t. New anchor is Smooth.
Sourcepub fn round_corners(&self, radius: f64) -> VectorPath
pub fn round_corners(&self, radius: f64) -> VectorPath
Round every Corner anchor by pulling back radius along both adjacent
edges and joining with a smooth curve (quarter-circle-ish cubic
approximation, k=0.5523 scaled by the pullback distance).
Sourcepub fn apply_edit(&mut self, edit: &AnchorEdit) -> Option<AnchorEdit>
pub fn apply_edit(&mut self, edit: &AnchorEdit) -> Option<AnchorEdit>
Apply an edit and return its exact inverse (None if out of range).